@@ -4,6 +4,10 @@ flavec = function(ddep,la,mu,K,r,lx,kk,n0)
    { 
        lavec = pmax(rep(0,lx),la - 1/(r + 1) * (la-mu)/K * ((0:(lx-1))+kk))
    } 
+   if(ddep == 1.3)
+   {
+       lavec = pmax(rep(0,lx),la * (1 - ((0:(lx-1))+kk)/K))
+   }
    if(ddep == 2 | ddep == 2.1 | ddep == 2.2) 
    {
        x = -(log(la/mu)/log(K+n0))^(ddep != 2.2)
